==> zzyj-outputvalcount-impl-3.0.0-20230621.070158-192-sources.jar: com/ejianc/business/outputvalcount/bean/ProjectInfoRegisterCommunicationEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 信息每日填报-外部沟通
 * 
 * @author generator
 * 
 */
 @TableName("t_project_info_register_communication")
public class ProjectInfoRegisterCommunicationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="complaint_org_id")
    private Long complaintOrgId; // 投诉单位id
    @TableField(value="complaint_org_name")
    private String complaintOrgName; // 投诉单位名称
    @TableField(value="file_name")
    private String fileName; // 函件名称
    @TableField(value="file_detail")
    private String fileDetail; // 投诉内容
    @TableField(value="remark")
    private String remark; // 描述
    @TableField(value="zhu_id")
    private Long zhuId; // 主表ID
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getComplaintOrgId() {
        return complaintOrgId;
    }

    public void setComplaintOrgId(Long complaintOrgId) {
        this.complaintOrgId = complaintOrgId;
    }
    public String getComplaintOrgName() {
        return complaintOrgName;
    }

    public void setComplaintOrgName(String complaintOrgName) {
        this.complaintOrgName = complaintOrgName;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileDetail() {
        return fileDetail;
    }

    public void setFileDetail(String fileDetail) {
        this.fileDetail = fileDetail;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    
}

==> zzyj-outputvalcount-impl-3.0.0-20230719.003916-207-sources.jar: com/ejianc/business/outputvalcount/bean/ProjectInfoRegisterCommunicationEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 信息每日填报-外部沟通
 * 
 * @author generator
 * 
 */
 @TableName("t_project_info_register_communication")
public class ProjectInfoRegisterCommunicationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="complaint_org_id")
    private Long complaintOrgId; // 投诉单位id
    @TableField(value="complaint_org_name")
    private String complaintOrgName; // 投诉单位名称
    @TableField(value="file_name")
    private String fileName; // 函件名称
    @TableField(value="file_detail")
    private String fileDetail; // 投诉内容
    @TableField(value="remark")
    private String remark; // 描述
    @TableField(value="zhu_id")
    private Long zhuId; // 主表ID
    @TableField(value="complaint_progress")
    private String complaintProgress; // 处理进展
    @TableField(value="complaint_result")
    private String complaintResult; // 处理结果
    @TableField(value="finish_time")
    private Date finishTime; // 完结时间


    public String getComplaintProgress() {
        return complaintProgress;
    }

    public void setComplaintProgress(String complaintProgress) {
        this.complaintProgress = complaintProgress;
    }

    public String getComplaintResult() {
        return complaintResult;
    }

    public void setComplaintResult(String complaintResult) {
        this.complaintResult = complaintResult;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getComplaintOrgId() {
        return complaintOrgId;
    }

    public void setComplaintOrgId(Long complaintOrgId) {
        this.complaintOrgId = complaintOrgId;
    }
    public String getComplaintOrgName() {
        return complaintOrgName;
    }

    public void setComplaintOrgName(String complaintOrgName) {
        this.complaintOrgName = complaintOrgName;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileDetail() {
        return fileDetail;
    }

    public void setFileDetail(String fileDetail) {
        this.fileDetail = fileDetail;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    
}
